define('io.ox/core/folder/api', {
    getDefaultFolder: function (type) {
        return (type === 'infostore') ? '/this/folder/' : undefined;
    },
    pool: { models: {} },
    path: _.constant($.when([])),
    can: _.constant($.when(false)),
    get: _.constant($.when({})),
    isExternalFileStorage: _.constant(false)
});
